﻿using Microsoft.EntityFrameworkCore;
using PaydayBackend.Models;

namespace PaydayBackend.Services;

public interface IPublicService
{
    public Task<IEnumerable<University>> GetAllUniversity();
    public Task<IEnumerable<UniversityDirection>?> GetAllUniversityDirectionByUniversityId(long universityId);
    // public Task<IEnumerable<LoanTerm> GetAllLoansByDirectionCost();
}

public class PublicService : IPublicService
{
    private DatabaseContext _databaseContext;

    public PublicService(DatabaseContext databaseContext)
    {
        _databaseContext = databaseContext;
    }
    
    public async Task<IEnumerable<University>> GetAllUniversity()
    {
        return await _databaseContext.Universities.ToListAsync();
    }
    
    public async Task<IEnumerable<UniversityDirection>?> GetAllUniversityDirectionByUniversityId(long universityId)
    {   
        if (await _databaseContext.Universities.Where(x => x.Id == universityId).FirstOrDefaultAsync() == null)
            return null;
        
        return await _databaseContext.UniversityDirections.Where(x => x.UniversityId == universityId).ToListAsync();
    }
    
}